Aspen is a filesystem router for Python web frameworks. See `aspen.io`_ for
framework wrappers.

.. _aspen.io: http://aspen.io/


Installation, Testing, and License
==================================

``aspen`` is available on `GitHub`_ and on `PyPI`_::

    $ pip install aspen

We test against 64-bit Python 2.7 and Python 3.6 on Linux: |travis|

And we test against 32- and 64-bit Python 2.7 on Windows: |appveyor|

``aspen`` is MIT-licensed.


.. _GitHub: https://github.com/AspenWeb/aspen.py
.. _PyPI: https://pypi.python.org/pypi/aspen
.. |travis| image:: https://img.shields.io/travis/AspenWeb/aspen.py/master.svg
   :target: https://travis-ci.org/AspenWeb/aspen.py
   :alt: Linux build status
.. |appveyor| image:: https://img.shields.io/appveyor/ci/AspenWeb/aspen-py/master.svg
   :target: https://ci.appveyor.com/project/AspenWeb/aspen-py
   :alt: Windows build status
